==> epassauth-0.0.9.5-sources.jar: com/bambooclod/eaccount3/api/QrAuth.java <==
package com.bambooclod.eaccount3.api;

import android.content.Context;
import android.util.Base64;
import android.widget.Toast;

import com.alibaba.fastjson.JSON;
import com.bambooclod.eaccount3.bean.JwtDecodeData;
import com.bambooclod.eaccount3.bean.QrAuthPara;
import com.bambooclod.eaccount3.bean.QrContentData;
import com.bambooclod.eaccount3.callback.AuthCallBack;
import com.bambooclod.epassbase.config.HttpConfig;
import com.bambooclod.epassbase.config.InitConfigValue;
import com.bambooclod.epassbase.log.LogUtil;
import com.bambooclod.epassbase.sp.SPUtils;
import com.bambooclod.epassbase.util.auth.V2SignUtil;

/**
 * Comment: //todo
 *
 * @author Vangelis.Wang in BambooCloud
 * @date 2019-06-14
 * Email:wangpei@bamboocloud.cn
 */
public class QrAuth {

    private QrAuth() {
    }

    public static final QrAuth authRequest = new QrAuth();

    public static QrAuth get() {
        return authRequest;
    }

    /**
     * 提供给Qr界面的认证方法
     *
     * @param context         Context
     * @param qrContent       二维码内容
     * @param mQrAuthCallBack 回调
     */
    public void authQR(Context context, String qrContent
            , final AuthCallBack mQrAuthCallBack) {
        String jwt = (String) SPUtils.get(context, InitConfigValue.USER_JWT, InitConfigValue.DEFAULT);
        QrAuthPara para;
        QrContentData parseQrContent;
        String session;
        if (InitConfigValue.DEFAULT.equals(jwt) && jwt != null) {
            Toast.makeText(context, "请登录后，再进行二维码扫描", Toast.LENGTH_SHORT).show();
            return;
        } else {
            //如果请求中含有JWT，表示为登录状态中的请求，则可以通过jwt去获取userinfo
            LogUtil.getInstance().w("Jwt:" + jwt);
            String[] forma = jwt.split("\\.");
            String jwtContent = new String(Base64.decode(forma[1], Base64.DEFAULT));
            JwtDecodeData decodeData = JSON.parseObject(jwtContent, JwtDecodeData.class);

            QrAuthPara.UserInfoBean userInfoBean =
                    new QrAuthPara.UserInfoBean(decodeData.getUserid()
                            , decodeData.getUserid(), "");


            //先去掉前缀
            String decryptPrefix = (String) SPUtils.get(context, InitConfigValue.QR_DECRYPT_PREFIX, InitConfigValue.DEFAULT);
            if (InitConfigValue.DEFAULT.equals(decryptPrefix)) {
                Toast.makeText(context, "当前未设置二维码解密前缀，无法认证，请前往主界面进行设置", Toast.LENGTH_SHORT).show();
                return;
            }
            LogUtil.getInstance().d("截取前的内容：" + qrContent);

            String formatPrefixQrContent;

            //前缀匹配判断
            if (qrContent.startsWith(decryptPrefix)) {
                formatPrefixQrContent = qrContent.substring(decryptPrefix.length());
            } else {
                Toast.makeText(context, "二维码解密前缀和后台不匹配，无法认证，请前往主界面进行设置", Toast.LENGTH_SHORT).show();
                return;
            }

            //国密解密
            String decryptKey = (String) SPUtils.get(context, InitConfigValue.QR_DECRYPT_KEY, InitConfigValue.DEFAULT);
            if (InitConfigValue.DEFAULT.equals(decryptKey)) {
                Toast.makeText(context, "当前未设置二维码解密秘钥，无法认证，请前往主界面进行设置", Toast.LENGTH_SHORT).show();
                return;
            }

            try {
                String decryptQrContent = V2SignUtil.decrypt(formatPrefixQrContent, decryptKey);
                parseQrContent = JSON.parseObject(decryptQrContent, QrContentData.class);
                para = new QrAuthPara(userInfoBean, parseQrContent.getCont());
                session = parseQrContent.getCont();
            } catch (Exception e) {
                e.printStackTrace();

                //这里是正常的，如果解密不了，那么返回原始字符串，并认证
                para = new QrAuthPara(userInfoBean, qrContent);
                session = qrContent;
            }
        }

        AuthRequest.get().doAuth(context, para, session
                , HttpConfig.AuthType.QR, false, new AuthCallBack() {
                    @Override
                    public void doAuthSuccess(String authList, String authedList) {
                        mQrAuthCallBack.doAuthSuccess(authList, authedList);
                    }

                    @Override
                    public void needBindDevice(String authList) {
                        mQrAuthCallBack.needBindDevice(authList);
                    }

                    @Override
                    public void error(String code, String message) {
                        mQrAuthCallBack.error(code, message);
                    }
                });
    }

}

==> epassauth-0.1.1.1-sources.jar: com/bambooclod/eaccount3/api/QrAuth.java <==
package com.bambooclod.eaccount3.api;

import android.content.Context;
import android.util.Base64;
import android.widget.Toast;

import com.alibaba.fastjson.JSON;
import com.bambooclod.eaccount3.bean.JwtDecodeData;
import com.bambooclod.eaccount3.bean.QrAuthPara;
import com.bambooclod.eaccount3.bean.QrContentData;
import com.bambooclod.eaccount3.callback.AuthCallBack;
import com.bambooclod.epassbase.config.HttpConfig;
import com.bambooclod.epassbase.config.InitConfigValue;
import com.bambooclod.epassbase.log.LogUtil;
import com.bambooclod.epassbase.sp.SPUtils;
import com.bambooclod.epassbase.util.auth.V2SignUtil;

/**
 * Comment: //todo
 *
 * @author Vangelis.Wang in BambooCloud
 * @date 2019-06-14
 * Email:wangpei@bamboocloud.cn
 */
public class QrAuth {

    private QrAuth() {
    }

    public static final QrAuth authRequest = new QrAuth();

    public static QrAuth get() {
        return authRequest;
    }

    /**
     * 提供给Qr界面的认证方法
     *
     * @param context         Context
     * @param qrContent       二维码内容
     * @param mQrAuthCallBack 回调
     */
    public void authQR(Context context, String qrContent
            , final AuthCallBack mQrAuthCallBack) {
        String jwt = (String) SPUtils.get(context, InitConfigValue.USER_JWT, InitConfigValue.DEFAULT);
        QrAuthPara para;
        QrContentData parseQrContent;
        String session;
        if (InitConfigValue.DEFAULT.equals(jwt) && jwt != null) {
            mQrAuthCallBack.error("NoJwt","请登录后，再进行二维码扫描");
            return;
        } else {
            //如果请求中含有JWT，表示为登录状态中的请求，则可以通过jwt去获取userinfo
            LogUtil.getInstance().w("Jwt:" + jwt);
            String[] forma = jwt.split("\\.");
            String jwtContent = new String(Base64.decode(forma[1], Base64.DEFAULT));
            JwtDecodeData decodeData = JSON.parseObject(jwtContent, JwtDecodeData.class);

            QrAuthPara.UserInfoBean userInfoBean =
                    new QrAuthPara.UserInfoBean(decodeData.getUserid()
                            , decodeData.getUserid(), "");


            //先去掉前缀
            String decryptPrefix = (String) SPUtils.get(context, InitConfigValue.QR_DECRYPT_PREFIX, InitConfigValue.DEFAULT);
            if (InitConfigValue.DEFAULT.equals(decryptPrefix)) {
                mQrAuthCallBack.error("NoQrPrefix","当前未设置二维码解密前缀，无法认证，请前往主界面进行设置");
                return;
            }
            LogUtil.getInstance().d("截取前的内容：" + qrContent);

            String formatPrefixQrContent;

            //前缀匹配判断
            if (qrContent.startsWith(decryptPrefix)) {
                formatPrefixQrContent = qrContent.substring(decryptPrefix.length());
            } else {
                mQrAuthCallBack.error("QrPrefixNotMatch","二维码解密前缀和后台不匹配，无法认证，请前往主界面进行设置");
                return;
            }

            //国密解密
            String decryptKey = (String) SPUtils.get(context, InitConfigValue.QR_DECRYPT_KEY, InitConfigValue.DEFAULT);
            if (InitConfigValue.DEFAULT.equals(decryptKey)) {
                mQrAuthCallBack.error("NoQrDecryptKey","当前未设置二维码解密秘钥，无法认证，请前往主界面进行设置");
                return;
            }

            try {
                String decryptQrContent = V2SignUtil.decrypt(formatPrefixQrContent, decryptKey);
                parseQrContent = JSON.parseObject(decryptQrContent, QrContentData.class);
                para = new QrAuthPara(userInfoBean, parseQrContent.getCont());
                session = parseQrContent.getCont();
            } catch (Exception e) {
                e.printStackTrace();

                //这里是正常的，如果解密不了，那么返回原始字符串，并认证
                para = new QrAuthPara(userInfoBean, qrContent);
                session = qrContent;
            }
        }

        AuthRequest.get().doAuth(context, para, session
                , HttpConfig.AuthType.QR, false, new AuthCallBack() {
                    @Override
                    public void doAuthSuccess(String authList, String authedList) {
                        mQrAuthCallBack.doAuthSuccess(authList, authedList);
                    }

                    @Override
                    public void needBindDevice(String authList) {
                        mQrAuthCallBack.needBindDevice(authList);
                    }

                    @Override
                    public void error(String code, String message) {
                        mQrAuthCallBack.error(code, message);
                    }
                });
    }

}
